{% extends "account/base.html" %}

{% load i18n bulma_tags %}

{% block head_title %}{% trans "Change Password" %}{% endblock %}

{% block content %}
  <h1>{% trans "Change Password" %}</h1>

  <form method="POST" action="{% url 'account_change_password' %}" class="password_change">
    {% csrf_token %}
    {{ form|bulma }}
    <button type="submit" name="action" class="button is-primary">{% trans "Change Password" %}</button>
  </form>
{% endblock %}
